#
# ZBabelTag
# (C) Copyright 2001 bluedynamics.com
# All Rights Reserved
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#  1. Redistributions of source code must retain the above copyright
#     notice, this list of conditions and the following disclaimer.
#  2. Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
# Author: Stephan Richter <srichter@iuveno-net.de>
#
# USAGE:
#
# <dtml-fish label="text" dst="language" [data="expr"] [towerId="'id'"]>
#
# label:   is the text that is being translated from the language label
# dst:     is the desired language that TheText is to be displayed in.
# data:    if the label is a data wrapper such as for dates and time, then
#          the data will provide the object that is being wrapped; this
#          attribute is optional.
# towerId: is the id of the tower this tag should use for its translation
#          this way one can easily separate content; this tag is also
#          optional
#
# You can use any designations you like for language.

from DocumentTemplate.DT_Util   import *
from DocumentTemplate.DT_String import String
from ZBabelTagsUtil             import BasicBabelTag, parseTagParameters



class FishTag(BasicBabelTag):
    '''Fish Tag class - Short-Cut version of the cool translation tag (babel)

       This tag is used to quickly translate menu-like text snippets, similar to
       the KDE translation.
    '''
    name = 'fish'

    literal = 1
    src     = 'label'
    attrs   = {'dst': 'en', 'label': '', 'data': None, 'towerId': None}


    def __init__(self, args):
        '''__init__(self, blocks) --> Initialize tag object; return None '''
        self.section = None
        args         = parseTagParameters(args, tag=self.name)
        self.args    = self.validateArguments(args) 
        
        for attr in self.attrs.keys():
            setattr(self, attr, self.attrs[attr])


    def render(self, md):
        """render(self, md) --> Do the Translation; return string"""
        self.defineAttributes(md)

        if self.data:
            data = self.data
            return eval(self.translate(self.label, md, makeNewEntries = 0))
        else:
            return self.translate(self.label, md, makeNewEntries = 0)



String.commands['fish'] = FishTag
           
