#
# ZBabelTag
# (C) Copyright 2000 The Internet (Aust) Pty Ltd
# ACN: 082 081 472  ABN: 83 082 081 472
# All Rights Reserved
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#  1. Redistributions of source code must retain the above copyright
#     notice, this list of conditions and the following disclaimer.
#  2. Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
# Author: Andrew Milton <akm@theinternet.com.au>
#
# USAGE:
#
# <dtml-babel src="language" dst="language" [literal="1"] [towerId="'id'"]>
# TheText
# </dtml-babel>
#
# src: is the language that TheText written in
# dst: is the desired language that TheText is to be displayed in.
# literal: if set means that parsing of the block text will not occur
# towerId: is the id of the tower this tag should use for its translation
#          this way one can easily separate content; this tag is also
#          optional
#
# You can use any designations you like for language.

from DocumentTemplate.DT_Util   import *
from DocumentTemplate.DT_String import String
from ZBabelTagsUtil             import BasicBabelTag, parseTagParameters
import string


class ZBabelTag(BasicBabelTag):
    '''ZBabel Tag class - The cool translation tag'''

    name='babel'
    blockContinuations=()


    def __init__(self, blocks):
        '''__init__(self, blocks) --> Initialize tag object; return None '''
        tname, args, section = blocks[0]

        self.section = section
        args         = parseTagParameters(args)
        self.args    = self.validateArguments(args) 

        for attr in self.attrs.keys():
            setattr(self, attr, self.attrs[attr])


    def render(self, md):
        """render(self, md) --> Do the Translation; return string"""

        srcText = ''
        object  = md.this
        self.defineAttributes(md)

        # Do we render the sub-blocks first and then translate?
        if self.literal in [1, '1', 'yes', 'true', 't']:
            srcText = string.strip(render_blocks(self.section.blocks, md))
            text    = self.translate(srcText, md)
        else:
            text    = self.smartTranslate(md)
            
        return text



String.commands['babel'] = ZBabelTag
           
